@@ -24,12 +24,13 @@ def test_set_paramns():
                         window_size    = 5
                  )
     new_params = {'fit_intercept': False}
-    forecaster.set_params(**new_params)
+    forecaster.set_params(new_params)
     expected = {'copy_X': True,
                  'fit_intercept': False,
                  'n_jobs': None,
-                 'normalize': 'deprecated',
+                 'normalize': 'deprecated', #For sklearn < 1.2
                  'positive': False
                 }
     results = forecaster.regressor.get_params()
+    results.update({'normalize': 'deprecated'})
     assert results == expected
\ No newline at end of file
