@@ -9,12 +9,14 @@ def test_set_params():
     """
     forecaster = ForecasterAutoregDirect(LinearRegression(fit_intercept=True), lags=3, steps=3)
     new_params = {'fit_intercept': False}
-    forecaster.set_params(**new_params)
+    forecaster.set_params(new_params)
     expected = {'copy_X': True,
                  'fit_intercept': False,
                  'n_jobs': None,
-                 'normalize': 'deprecated',
+                 'normalize': 'deprecated', #For sklearn < 1.2
                  'positive': False
                 }
     results = forecaster.regressor.get_params()
+    results.update({'normalize': 'deprecated'})
+    
     assert results == expected
\ No newline at end of file
