@@ -51,12 +51,12 @@ def test_exception_bayesian_search_optuna_metric_list_duplicate_names():
     n_validation = 12
     y_train = y[:-n_validation]
     lags_grid = [2, 4]
-    def search_space(trial):
+    def search_space(trial): # pragma: no cover
         search_space  = {'alpha' : trial.suggest_loguniform('not_alpha', 1e-2, 1.0)
                         }
         return search_space
 
-    err_msg = re.escape('When `metrics` is a `list`, each metric name must be unique.')
+    err_msg = re.escape('When `metric` is a `list`, each metric name must be unique.')
     with pytest.raises(ValueError, match = err_msg):
         _bayesian_search_optuna(
             forecaster         = forecaster,
@@ -127,7 +127,6 @@ def test_results_output_bayesian_search_optuna_ForecasterAutoreg_with_mocked():
     Test output of _bayesian_search_optuna in ForecasterAutoreg with mocked
     (mocked done in Skforecast v0.4.3).
     """
-
     forecaster = ForecasterAutoreg(
                     regressor = RandomForestRegressor(random_state=123),
                     lags      = 2 # Placeholder, the value will be overwritten
@@ -140,7 +139,7 @@ def test_results_output_bayesian_search_optuna_ForecasterAutoreg_with_mocked():
 
     def search_space(trial):
         search_space  = {'n_estimators'     : trial.suggest_int('n_estimators', 10, 20),
-                         'min_samples_leaf' : trial.suggest_float('min_samples_leaf', 1., 3.7, log=True),
+                         'min_samples_leaf' : trial.suggest_float('min_samples_leaf', 0.1, 1., log=True),
                          'max_features'     : trial.suggest_categorical('max_features', ['log2', 'sqrt'])
                         } 
         return search_space
@@ -162,50 +161,47 @@ def test_results_output_bayesian_search_optuna_ForecasterAutoreg_with_mocked():
               )[0]
     
     expected_results = pd.DataFrame({
-            'lags'  :[[1, 2], [1, 2], [1, 2], [1, 2], [1, 2], [1, 2], [1, 2], [1, 2], [1, 2], [1, 2],
-                      [1, 2, 3, 4], [1, 2, 3, 4], [1, 2, 3, 4], [1, 2, 3, 4], [1, 2, 3, 4],
-                      [1, 2, 3, 4], [1, 2, 3, 4], [1, 2, 3, 4], [1, 2, 3, 4], [1, 2, 3, 4]],
-            'params':[{'n_estimators': 17, 'min_samples_leaf': 1.4540684905340955, 'max_features': 'sqrt'}, 
-                      {'n_estimators': 17, 'min_samples_leaf': 1.7394414709444481, 'max_features': 'log2'}, 
-                      {'n_estimators': 15, 'min_samples_leaf': 1.670328340553618, 'max_features': 'sqrt'}, 
-                      {'n_estimators': 14, 'min_samples_leaf': 1.0812075849925713, 'max_features': 'sqrt'}, 
-                      {'n_estimators': 12, 'min_samples_leaf': 1.2580328751834622, 'max_features': 'sqrt'}, 
-                      {'n_estimators': 16, 'min_samples_leaf': 3.038425623453048, 'max_features': 'log2'}, 
-                      {'n_estimators': 17, 'min_samples_leaf': 1.5258288130500341, 'max_features': 'log2'},
-                      {'n_estimators': 13, 'min_samples_leaf': 2.2830831111754475, 'max_features': 'sqrt'},
-                      {'n_estimators': 14, 'min_samples_leaf': 1.9077116138625934, 'max_features': 'log2'},
-                      {'n_estimators': 14, 'min_samples_leaf': 3.2182906443995143, 'max_features': 'log2'},
-                      {'n_estimators': 17, 'min_samples_leaf': 1.4540684905340955, 'max_features': 'sqrt'}, 
-                      {'n_estimators': 17, 'min_samples_leaf': 1.7394414709444481, 'max_features': 'log2'}, 
-                      {'n_estimators': 15, 'min_samples_leaf': 1.670328340553618, 'max_features': 'sqrt'}, 
-                      {'n_estimators': 14, 'min_samples_leaf': 1.0812075849925713, 'max_features': 'sqrt'}, 
-                      {'n_estimators': 12, 'min_samples_leaf': 1.2580328751834622, 'max_features': 'sqrt'}, 
-                      {'n_estimators': 16, 'min_samples_leaf': 3.038425623453048, 'max_features': 'log2'}, 
-                      {'n_estimators': 17, 'min_samples_leaf': 1.5258288130500341, 'max_features': 'log2'}, 
-                      {'n_estimators': 13, 'min_samples_leaf': 2.2830831111754475, 'max_features': 'sqrt'}, 
-                      {'n_estimators': 14, 'min_samples_leaf': 1.9077116138625934, 'max_features': 'log2'}, 
-                      {'n_estimators': 14, 'min_samples_leaf': 3.2182906443995143, 'max_features': 'log2'}],
-            'mean_absolute_error':np.array([0.21433589521377985, 0.21433589521377985, 0.21479600790277778, 
-                                            0.21661388810185186, 0.21685103020640437, 0.2152253922034143,
-                                            0.21433589521377985, 0.21739975926994304, 0.21661388810185186,
-                                            0.21661388810185186, 0.20997867726211075, 0.20997867726211075,
-                                            0.20840381228758173, 0.20952958306022407, 0.20980140118464055, 
-                                            0.21045872919117656, 0.20997867726211075, 0.20775872275075422,
-                                            0.20952958306022407, 0.20952958306022407]),                                                               
-            'n_estimators' :np.array([17, 17, 15, 14, 12, 16, 17, 13, 14, 14,
-                                      17, 17, 15, 14, 12, 16, 17, 13, 14, 14]),
-            'min_samples_leaf' :np.array([1.4540684905340955, 1.7394414709444481, 1.670328340553618, 
-                                          1.0812075849925713, 1.2580328751834622, 3.038425623453048,
-                                          1.5258288130500341, 2.2830831111754475, 1.9077116138625934,
-                                          3.2182906443995143, 1.4540684905340955, 1.7394414709444481, 
-                                          1.670328340553618, 1.0812075849925713, 1.2580328751834622,
-                                          3.038425623453048, 1.5258288130500341, 2.2830831111754475,
-                                          1.9077116138625934, 3.2182906443995143]),
-            'max_features' :['sqrt', 'log2', 'sqrt', 'sqrt', 'sqrt', 'log2', 'log2', 'sqrt', 'log2', 
-                             'log2', 'sqrt', 'log2', 'sqrt', 'sqrt', 'sqrt', 'log2', 'log2', 'sqrt', 
-                             'log2', 'log2']
+            'lags'  :[[1, 2, 3, 4], [1, 2, 3, 4], [1, 2, 3, 4], [1, 2], [1, 2], [1, 2],
+                      [1, 2], [1, 2], [1, 2, 3, 4], [1, 2], [1, 2, 3, 4], [1, 2], [1, 2],
+                      [1, 2], [1, 2, 3, 4], [1, 2], [1, 2, 3, 4], [1, 2, 3, 4], [1, 2, 3, 4],
+                      [1, 2, 3, 4]],
+            'params':[{'n_estimators': 13, 'min_samples_leaf': 0.42753938073418213, 'max_features': 'sqrt'},
+                        {'n_estimators': 14, 'min_samples_leaf': 0.782328520465639, 'max_features': 'log2'},
+                        {'n_estimators': 16, 'min_samples_leaf': 0.707020154488976, 'max_features': 'log2'},
+                        {'n_estimators': 16, 'min_samples_leaf': 0.707020154488976, 'max_features': 'log2'},
+                        {'n_estimators': 14, 'min_samples_leaf': 0.782328520465639, 'max_features': 'log2'},
+                        {'n_estimators': 12, 'min_samples_leaf': 0.14977928606210794, 'max_features': 'sqrt'},
+                        {'n_estimators': 13, 'min_samples_leaf': 0.42753938073418213, 'max_features': 'sqrt'},
+                        {'n_estimators': 14, 'min_samples_leaf': 0.3116628929828935, 'max_features': 'log2'},
+                        {'n_estimators': 14, 'min_samples_leaf': 0.3116628929828935, 'max_features': 'log2'},
+                        {'n_estimators': 17, 'min_samples_leaf': 0.21035794225904136, 'max_features': 'log2'},
+                        {'n_estimators': 17, 'min_samples_leaf': 0.21035794225904136, 'max_features': 'log2'},
+                        {'n_estimators': 17, 'min_samples_leaf': 0.19325882509735576, 'max_features': 'sqrt'},
+                        {'n_estimators': 15, 'min_samples_leaf': 0.2466706727024324, 'max_features': 'sqrt'},
+                        {'n_estimators': 17, 'min_samples_leaf': 0.2649149454284987, 'max_features': 'log2'},
+                        {'n_estimators': 15, 'min_samples_leaf': 0.2466706727024324, 'max_features': 'sqrt'},
+                        {'n_estimators': 14, 'min_samples_leaf': 0.1147302385573586, 'max_features': 'sqrt'},
+                        {'n_estimators': 17, 'min_samples_leaf': 0.2649149454284987, 'max_features': 'log2'},
+                        {'n_estimators': 17, 'min_samples_leaf': 0.19325882509735576, 'max_features': 'sqrt'},
+                        {'n_estimators': 14, 'min_samples_leaf': 0.1147302385573586, 'max_features': 'sqrt'},
+                        {'n_estimators': 12, 'min_samples_leaf': 0.14977928606210794, 'max_features': 'sqrt'}],
+            'mean_absolute_error':np.array([0.2077587228, 0.2095295831, 0.2104587292, 0.2152253922,
+                                            0.2166138881, 0.2173338079, 0.2173997593, 0.2212038456,
+                                            0.2213244194, 0.2228916722, 0.2229839748, 0.2235827592,
+                                            0.2247429583, 0.2254556258, 0.2263380591, 0.2276488527,
+                                            0.2288371667, 0.2323304396, 0.2373974755, 0.2407737066]),                                                               
+            'n_estimators' :np.array([13, 14, 16, 16, 14, 12, 13, 14, 14, 17, 17, 17, 15, 17, 15,
+                                      14, 17, 17, 14, 12]),
+            'min_samples_leaf' :np.array([0.4275393807, 0.7823285205, 0.7070201545, 0.7070201545,
+                                          0.7823285205, 0.1497792861, 0.4275393807, 0.311662893 ,
+                                          0.311662893 , 0.2103579423, 0.2103579423, 0.1932588251,
+                                          0.2466706727, 0.2649149454, 0.2466706727, 0.1147302386,
+                                          0.2649149454, 0.1932588251, 0.1147302386, 0.1497792861]),
+            'max_features' :['sqrt', 'log2', 'log2', 'log2', 'log2', 'sqrt', 'sqrt', 'log2',
+                             'log2', 'log2', 'log2', 'sqrt', 'sqrt', 'log2', 'sqrt', 'sqrt',
+                             'log2', 'sqrt', 'sqrt', 'sqrt']
                                      },
-            index=list(range(20))
+            index=[17, 19, 15, 5, 9, 4, 7, 8, 18, 6, 16, 0, 2, 1, 12, 3, 11, 10, 13, 14]
                                    ).sort_values(by='mean_absolute_error', ascending=True)
 
     pd.testing.assert_frame_equal(results, expected_results, check_dtype=False)
@@ -459,7 +455,7 @@ def test_results_output_bayesian_search_optuna_ForecasterAutoregCustom_with_mock
 
 def test_evaluate_bayesian_search_optuna_when_return_best():
     """
-    Test forecaster is refited when return_best=True in _bayesian_search_optuna.
+    Test forecaster is refitted when return_best=True in _bayesian_search_optuna.
     """
     forecaster = ForecasterAutoreg(
                     regressor = Ridge(random_state=123),
