@@ -6,18 +6,22 @@
 ################################################################################
 # coding=utf-8
 
-
-from typing import Union, Tuple, Optional
+from typing import Union, Tuple, Optional, Callable
+import logging
 import numpy as np
 import pandas as pd
-import logging
-from tqdm import tqdm
+import warnings
 from sklearn.model_selection import ParameterGrid
-from statsmodels.tsa.statespace.sarimax import SARIMAX
-
+from tqdm import tqdm
+from ..utils import check_optional_dependency
 from ..model_selection import time_series_splitter
 from ..model_selection.model_selection import _get_metric
 
+try:
+    from statsmodels.tsa.statespace.sarimax import SARIMAX
+except Exception as e:
+    package_name = str(e).split(" ")[-1].replace("'", "")
+    check_optional_dependency(package_name=package_name)
 
 logging.basicConfig(
     format = '%(asctime)-5s %(name)-10s %(levelname)-5s %(message)s', 
@@ -26,23 +30,22 @@ logging.basicConfig(
 
 
 def backtesting_sarimax(
-        y: pd.Series,
-        steps: int,
-        metric: Union[str, callable],
-        initial_train_size: int,
-        fixed_train_size: bool=False,
-        refit: bool=False,
-        order: tuple=(1, 0, 0), 
-        seasonal_order: tuple=(0, 0, 0, 0),
-        trend: str=None,
-        alpha: float= 0.05,
-        exog: Optional[Union[pd.Series, pd.DataFrame]]=None,
-        sarimax_kwargs: dict={},
-        fit_kwargs: dict={'disp':0},
-        verbose: bool=False
+    y: pd.Series,
+    steps: int,
+    metric: Union[str, Callable],
+    initial_train_size: int,
+    fixed_train_size: bool=False,
+    refit: bool=False,
+    order: tuple=(1, 0, 0), 
+    seasonal_order: tuple=(0, 0, 0, 0),
+    trend: str=None,
+    alpha: float= 0.05,
+    exog: Optional[Union[pd.Series, pd.DataFrame]]=None,
+    sarimax_kwargs: dict={},
+    fit_kwargs: dict={'disp':0},
+    verbose: bool=False
 ) -> Tuple[float, pd.DataFrame]:
-    '''
-    
+    """
     Backtesting (validation) of `SARIMAX` model from statsmodels >= 0.12. The model
     is trained using the `initial_train_size` first observations, then, in each
     iteration, a number of `steps` predictions are evaluated. If refit is `True`,
@@ -58,13 +61,13 @@ def backtesting_sarimax(
     steps : int
         Number of steps to predict.
 
-    metric : str, callable
+    metric : str, Callable
         Metric used to quantify the goodness of fit of the model.
         
         If string:
             {'mean_squared_error', 'mean_absolute_error', 'mean_absolute_percentage_error'}
 
-        If callable:
+        If Callable:
             Function with arguments y_true, y_pred that returns a float.
 
     initial_train_size: int 
@@ -132,7 +135,16 @@ def backtesting_sarimax(
                 column pred   = predictions.
                 column lower  = lower bound of the interval.
                 column upper  = upper bound interval of the interval.
-    '''
+    
+    """
+
+    warnings.warn(
+        ('The `model_selection_statsmodels` module is deprecated and will be removed '
+         'in a future version of Skforecast. Instead, a forecaster based on ARIMA ' 
+         'models, `ForecasterSarimax`, and the `model_selection_sarimax` module, ' 
+         'for model evaluation and optimization, have been created.\n\n'
+         'Docs: https://joaquinamatrodrigo.github.io/skforecast/latest/user_guides/forecasting-sarimax-arima.html')
+    )
 
     if isinstance(metric, str):
         metric = _get_metric(metric=metric)
@@ -384,7 +396,7 @@ def cv_sarimax(
         y: pd.Series,
         initial_train_size: int,
         steps: int,
-        metric: Union[str, callable],
+        metric: Union[str, Callable],
         order: tuple=(1, 0, 0), 
         seasonal_order: tuple=(0, 0, 0, 0),
         trend: str=None,
@@ -395,9 +407,7 @@ def cv_sarimax(
         fit_kwargs: dict={'disp':0},
         verbose: bool=False
 ) -> Tuple[np.array, np.array]:
-
-    '''
-    
+    """
     Cross-validation of `SARIMAX` model from statsmodels >= 0.12. The order of data
     is maintained and the training set increases in each iteration.
     
@@ -442,13 +452,13 @@ def cv_sarimax(
     steps : int
         Number of steps to predict.
         
-    metric : str, callable
+    metric : str, Callable
         Metric used to quantify the goodness of fit of the model.
         
         If string:
             {'mean_squared_error', 'mean_absolute_error', 'mean_absolute_percentage_error'}
 
-        If callable:
+        If Callable:
             Function with arguments y_true, y_pred that returns a float.
         
     exog : pandas Series, pandas DataFrame, default `None`
@@ -477,7 +487,16 @@ def cv_sarimax(
                 column pred   = predictions.
                 column lower  = lower bound of the interval.
                 column upper  = upper bound interval of the interval.
-    '''
+    
+    """
+
+    warnings.warn(
+        ('The `model_selection_statsmodels` module is deprecated and will be removed '
+         'in a future version of Skforecast. Instead, a forecaster based on ARIMA ' 
+         'models, `ForecasterSarimax`, and the `model_selection_sarimax` module, ' 
+         'for model evaluation and optimization, have been created.\n\n'
+         'Docs: https://joaquinamatrodrigo.github.io/skforecast/latest/user_guides/forecasting-sarimax-arima.html')
+    )
     
     if isinstance(metric, str):
         metric = _get_metric(metric=metric)
@@ -542,7 +561,7 @@ def grid_search_sarimax(
         y: pd.Series,
         param_grid: dict,
         steps: int,
-        metric: Union[str, callable],
+        metric: Union[str, Callable],
         initial_train_size: int,
         fixed_train_size: bool=False,
         exog: Union[pd.Series, pd.DataFrame]=None,
@@ -551,8 +570,7 @@ def grid_search_sarimax(
         fit_kwargs: dict={'disp':0},
         verbose: bool=False
 ) -> pd.DataFrame:
-    '''
-
+    """
     Exhaustive search over specified parameter values for a `SARIMAX` model from
     statsmodels >= 0.12. Validation is done using time series cross-validation or
     backtesting.
@@ -570,13 +588,13 @@ def grid_search_sarimax(
     steps : int
         Number of steps to predict.
         
-    metric : str, callable
+    metric : str, Callable
         Metric used to quantify the goodness of fit of the model.
         
         If string:
             {'mean_squared_error', 'mean_absolute_error', 'mean_absolute_percentage_error'}
 
-        If callable:
+        If Callable:
             Function with arguments y_true, y_pred that returns a float.
 
     initial_train_size: int 
@@ -612,7 +630,15 @@ def grid_search_sarimax(
             column metric = metric value estimated for the combination of parameters.
             additional n columns with param = value.
 
-    '''
+    """
+
+    warnings.warn(
+        ('The `model_selection_statsmodels` module is deprecated and will be removed '
+         'in a future version of Skforecast. Instead, a forecaster based on ARIMA ' 
+         'models, `ForecasterSarimax`, and the `model_selection_sarimax` module, ' 
+         'for model evaluation and optimization, have been created.\n\n'
+         'Docs: https://joaquinamatrodrigo.github.io/skforecast/latest/user_guides/forecasting-sarimax-arima.html')
+    )
 
     params_list = []
     metric_list = []
